
import sys
import support

# Java Package Import Failure
#------------------------------------------------------------------------------
# Because 'org' is an already created java package, the search for
# 'org.subpackage' is delegated to org '__findattr_ex__' method and the
# 'imp.find_module' static method is never called.
# Too bad, because it means that the added sys.path entry will never get
# turned into a SyspathArchive instance, and the associated java package
# hierarchy will never get created.
# Two hacks (short-term) are proposed to 'make it work' ... sort of.
#
# Sebastien.Boisgerault@ensmp.fr

def hack1():
    """
    Make an import that fails

    A not-very-subtle method to ensure that 'imp.find_module' gets called and
    that all sys.path entries that are candidates for 'SyspathArchive'ification
    are considered.
    """
    try:
        import __NOT_A_CHANCE__
    except ImportError:
        pass

def hack2():
    """
    Turn manually your jar sys.path entry into a SyspathArchive instance.
    """
    import org.python.core.SyspathArchive as SA
    sys.path[-1] = SA(sys.path[-1])

TEST_NUMBER = __file__[-6:-3]

try: # should work (if 'org.python.core' is in the path for example)
    import org
except ImportError:
    # anyway if it doesn't, we need 'org' created and registered
    org = sys.add_package("org")
    sys.modules["org"] = org

sys.path.append("test%sjar/org.subpackage.jar" % TEST_NUMBER)
# Pick your hack to make it work:
# hack1()
# hack2()

try:
    import org.subpackage
except ImportError:
    raise support.TestWarning("'import org.subpackage' failed")
